package api

import (
	"ZhenTuLocalPassiveAdapter/config"
	"ZhenTuLocalPassiveAdapter/dto"
	"bytes"
	"encoding/json"
	"io"
	"log"
	"net/http"
)

func QueryUploadUrlForTask(taskId string) (string, error) {
	url := config.Config.Api.BaseUrl + "/" + taskId + "/uploadUrl"
	req, err := http.NewRequest("POST", url, nil)
	if err != nil {
		log.Println("Error creating request:", err)
		return "", err
	}
	client := &http.Client{}
	resp, err := client.Do(req)
	if err != nil {
		log.Println("Error sending request:", err)
		return "", err
	}
	defer resp.Body.Close()
	body, err := io.ReadAll(resp.Body)
	if err != nil {
		log.Println("Error reading response body:", err)
		return "", err
	}
	return string(body), nil
}

func ReportTaskFailure(taskId string) {
	url := config.Config.Api.BaseUrl + "/" + taskId + "/failure"

	req, err := http.NewRequest("POST", url, nil)
	if err != nil {
		log.Println("Error creating request:", err)
		return
	}
	client := &http.Client{}
	resp, err := client.Do(req)
	if err != nil {
		log.Println("Error sending request:", err)
		return
	}
	defer resp.Body.Close()
}

func ReportTaskSuccess(taskId string, file *dto.FileObject) {
	url := config.Config.Api.BaseUrl + "/" + taskId + "/success"
	jsonData, err := json.Marshal(file)
	if err != nil {
		log.Println("Error marshaling JSON:", err)
		return
	}
	req, err := http.NewRequest("POST", url, bytes.NewBuffer(jsonData))
	if err != nil {
		log.Println("Error creating request:", err)
		return
	}
	req.Header.Set("Content-Type", "application/json")
	client := &http.Client{}
	resp, err := client.Do(req)
	if err != nil {
		log.Println("Error sending request:", err)
		return
	}
	defer resp.Body.Close()
}
